Re-exports
pub use pi::find_pi_session_file;pub use pi::ingest_pi_transcript_delta;pub use pi::pi_session_dir_for_cwd;pub use pi::PiIngestStats;
Modules
- pi
- Pi session transcript discovery, delta ingestion, and ledger normalization (GH-577).
Structs
Enums
Functions
- classify_
record - Classify a transcript JSONL record.
- extract_
last_ assistant_ text - Extract the last assistant text message from a stored transcript JSONL.
- ingest_
transcript_ delta - Perform cursor-based delta ingest from a Claude transcript JSONL file.